==> jangaroo-sdk-0.9.3.zip: joo/classes/flash/ui/ContextMenuClipboardItems.js <==
joo.classLoader.prepare("package flash.ui",/* {*/


/**
 * The ContextMenuClipboardItems class lets you enable or disable the commands in the clipboard context menu.
 * <p>Enable or disable the context menu clipboard commands using the <code>clipboardItems</code> property of the ContextMenu object. The <code>clipboardItems</code> property is an instance of this ContextMenuClipboardItems class. The clipboard context menu is shown in a context menu when the <code>clipboardMenu</code> property of the context menu is <code>true</code>, unless the context menu is for a TextField object. TextField objects control the display of the context menu and the state of its clipboard items automatically.</p>
 * @see ContextMenu#clipboardMenu
 *
 */
"public final class ContextMenuClipboardItems",1,function($$private){;return[ 
  /**
   * Enables or disables the 'Delete' or 'Clear' item on the clipboard menu. This should be enabled only if an object that can be cleared is selected.
   */
  "public function get clear",function clear$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set clear",function clear$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Enables or disables the 'Copy' item on the clipboard menu. This should be enabled only if an object that can be copied is selected.
   */
  "public function get copy",function copy$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set copy",function copy$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Enables or disables the 'Cut' item on the clipboard menu. This should be enabled only if an object that can be cut is selected.
   */
  "public function get cut",function cut$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set cut",function cut$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Enables or disables the 'Paste' item on the clipboard menu. This should be enabled only if pastable data is on the clipboard.
   */
  "public function get paste",function paste$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set paste",function paste$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Enables or disables the 'Select All' item on the clipboard menu. This should only be enabled in a context where a selection can be expanded to include all similar items, such as in a list or a text editing control.
   */
  "public function get selectAll",function selectAll$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set selectAll",function selectAll$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Creates a new ContextMenuClipboardItems object.
   */
  "public function ContextMenuClipboardItems",function ContextMenuClipboardItems$() {
    throw new Error('not implemented'); // TODO: implement!
  },
];},[],["Error"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/flash/ui/ContextMenuClipboardItems.js <==
joo.classLoader.prepare("package flash.ui",/* {*/


/**
 * The ContextMenuClipboardItems class lets you enable or disable the commands in the clipboard context menu.
 * <p>Enable or disable the context menu clipboard commands using the <code>clipboardItems</code> property of the ContextMenu object. The <code>clipboardItems</code> property is an instance of this ContextMenuClipboardItems class. The clipboard context menu is shown in a context menu when the <code>clipboardMenu</code> property of the context menu is <code>true</code>, unless the context menu is for a TextField object. TextField objects control the display of the context menu and the state of its clipboard items automatically.</p>
 * @see ContextMenu#clipboardMenu
 *
 */
"public final class ContextMenuClipboardItems",1,function($$private){return[ 
  /**
   * Enables or disables the 'Delete' or 'Clear' item on the clipboard menu. This should be enabled only if an object that can be cleared is selected.
   */
  "public function get clear",function clear$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set clear",function clear$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Enables or disables the 'Copy' item on the clipboard menu. This should be enabled only if an object that can be copied is selected.
   */
  "public function get copy",function copy$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set copy",function copy$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Enables or disables the 'Cut' item on the clipboard menu. This should be enabled only if an object that can be cut is selected.
   */
  "public function get cut",function cut$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set cut",function cut$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Enables or disables the 'Paste' item on the clipboard menu. This should be enabled only if pastable data is on the clipboard.
   */
  "public function get paste",function paste$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set paste",function paste$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Enables or disables the 'Select All' item on the clipboard menu. This should only be enabled in a context where a selection can be expanded to include all similar items, such as in a list or a text editing control.
   */
  "public function get selectAll",function selectAll$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set selectAll",function selectAll$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Creates a new ContextMenuClipboardItems object.
   */
  "public function ContextMenuClipboardItems",function ContextMenuClipboardItems() {
    throw new Error('not implemented'); // TODO: implement!
  },
undefined];},[],["Error"], "0.8.0", "0.9.12"
);
